@@ -15,7 +15,7 @@ use List::MoreUtils        qw( any none );
 use Term::Choose           qw( choose );
 use Term::ReadLine::Simple qw();
 
-use App::YTDL::Helper qw( check_encode_stdout );
+use App::YTDL::Helper qw( check_mapping_stdout );
 
 
 
@@ -24,7 +24,7 @@ sub _my_sort {
     my @s = $sort_order eq 'Asc'
                 ? ( $h_ref->{$a}{$sort_item}, $h_ref->{$b}{$sort_item} )
                 : ( $h_ref->{$b}{$sort_item}, $h_ref->{$a}{$sort_item} );
-    if ( $sort_item eq 'view_count_raw' ) {
+    if ( $sort_item eq 'view_count_raw' || $sort_item eq 'date_sort' ) {
        $s[0] <=> $s[1] || $h_ref->{$a}{title} cmp $h_ref->{$b}{title};
     }
     else {
@@ -35,22 +35,25 @@ sub _my_sort {
 
 sub choose_videos {
     my ( $opt, $info, $tmp, $ex, $prompt ) = @_;
-    my $length_view_count = 0;
-    my $length_video_id   = 0;
-    my $has_upload_date   = 0;
-    my $has_view_count    = 0;
-    my $has_duration      = 0;
+    my $length_view_count  = 0;
+    my $length_video_id    = 0;
+    my $length_upload_date = 0;
+    my $has_date_sort      = 0;
+    my $has_view_count     = 0;
+    my $has_duration       = 0;
     for my $video_id ( keys %{$tmp->{$ex}} ) {
-        $has_view_count++  if $tmp->{$ex}{$video_id}{view_count};
-        $has_upload_date++ if $tmp->{$ex}{$video_id}{upload_date} ne '0000-00-00';
-        $has_duration++    if $tmp->{$ex}{$video_id}{duration}    ne '-:--:--';
-        if ( length $video_id > $length_video_id ) {
-            $length_video_id = length $video_id;
-        }
-        if ( length $tmp->{$ex}{$video_id}{view_count} > $length_view_count ) {
-            $length_view_count = length $tmp->{$ex}{$video_id}{view_count};
+        $has_duration++                                                if $tmp->{$ex}{$video_id}{duration} ne '-:--:--';
+        $has_date_sort++                                               if $tmp->{$ex}{$video_id}{date_sort};
+        $has_view_count++                                              if $tmp->{$ex}{$video_id}{view_count};
+        $length_video_id   = length $video_id                          if length $video_id > $length_video_id;
+        $length_view_count = length $tmp->{$ex}{$video_id}{view_count} if length $tmp->{$ex}{$video_id}{view_count} > $length_view_count;
+        if ( $tmp->{$ex}{$video_id}{upload_date} ne '0000-00-00' && length $tmp->{$ex}{$video_id}{upload_date} > $length_upload_date ) {
+            $length_upload_date = length $tmp->{$ex}{$video_id}{upload_date};
         }
     }
+    if ( $length_upload_date && $length_upload_date < 10 ) {
+        $length_upload_date = 10;
+    }
     my $regexp;
     my $back   = sprintf "%*s", $length_video_id, '   BACK';
     my $filter = sprintf "%*s", $length_video_id, ' FILTER';
@@ -73,9 +76,15 @@ sub choose_videos {
         if ( $sort_item eq 'duration' && ! $has_duration ) {
             $sort_item = 'upload_date';
         }
-        if ( $sort_item eq 'upload_date' && ! $has_upload_date ) {
-            $sort_item = 'title';
-            $sort_order = 'Asc';
+        if ( $sort_item eq 'upload_date' ) {
+            if ( ! $length_upload_date ) {
+                $sort_item = 'title';
+                $sort_order = 'Asc';
+            }
+            elsif ( $has_date_sort ) {
+                $sort_item = 'date_sort';
+                $sort_order = $sort_order eq 'Asc' ? 'Desc' : 'Asc';
+            }
         }
         my @video_ids = sort { _my_sort( $sort_item, $sort_order, $tmp->{$ex}, $a, $b ) }  keys %{$tmp->{$ex}};
 
@@ -94,14 +103,12 @@ sub choose_videos {
             if ( $ex eq 'youtube' ) {
                 $tmp->{$ex}{$video_id}{extractor} = 'youtube';
             }
-            if ( $Encode::Locale::ENCODING_CONSOLE_OUT !~ /^UTF-/i ) {
-                $title = decode( 'console_out', check_encode_stdout( $opt, $title ) );
-            }
+            $title = check_mapping_stdout( $opt, $title ) if $Encode::Locale::ENCODING_CONSOLE_OUT !~ /^UTF-/i;
             $has_view_count = 0 if $opt->{list_sort_item} ne 'view_count_raw' && ! $opt->{show_view_count};
             my $line = sprintf "%*s |", $length_video_id, $video_id;
-            $line .= sprintf " %7s", $tmp->{$ex}{$video_id}{duration}                        if $has_duration;
-            $line .= sprintf "  %10s", $tmp->{$ex}{$video_id}{upload_date}                   if $has_upload_date;
-            $line .= sprintf "  %*s", $length_view_count, $tmp->{$ex}{$video_id}{view_count} if $has_view_count;
+            $line .= sprintf " %7s", $tmp->{$ex}{$video_id}{duration}                          if $has_duration;
+            $line .= sprintf "  %*s", $length_upload_date, $tmp->{$ex}{$video_id}{upload_date} if $length_upload_date;
+            $line .= sprintf "  %*s", $length_view_count, $tmp->{$ex}{$video_id}{view_count}   if $has_view_count;
             $line .= sprintf "  %s", $title;
             push @videos, $line;
             push @tmp_video_ids, $video_id;
