@@ -16,7 +16,6 @@ use Encode::Locale     qw();
 use LWP::UserAgent     qw();
 use Term::ANSIScreen   qw( :cursor :screen );
 use Term::Choose::Util qw( insert_sep );
-use Try::Tiny          qw( try catch );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
@@ -34,14 +33,14 @@ sub download_youtube {
         for my $video_id ( sort { $info->{$ex}{$a}{count} <=> $info->{$ex}{$b}{count} } keys %{$info->{$ex}} ) {
             for my $fmt ( sort keys %{$info->{$ex}{$video_id}{file_name}} ) {
                 my $file_name = $info->{$ex}{$video_id}{file_name}{$fmt};
-                try {
+                if ( ! eval {
                     unlink encode_fs( $opt, $file_name ) or die encode_fs( $opt, $file_name ) . " $!" if -f encode_fs( $opt, $file_name ) && $opt->{overwrite};
                     _download_video( $opt, $info, $ex, $video_id, $fmt, $nr );
                     timestamp_to_upload_date( $opt, $info, $ex, $video_id, $file_name ) if $opt->{modify_timestamp};
+                    1 }
+                ) {
+                    say "$video_id - ", check_mapping_stdout( $opt, $@ );
                 }
-                catch {
-                    say "$video_id - ", check_mapping_stdout( $opt, $_ );
-                };
                 $nr++;
             }
         }
