@@ -13,7 +13,6 @@ use JSON                qw( decode_json );
 use LWP::UserAgent      qw();
 #use Mojo::DOM          qw(); # required
 use Term::ANSIScreen    qw( :screen );
-use Try::Tiny           qw( try catch );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
@@ -34,22 +33,21 @@ sub get_yt_list_info {
     my $count = 0;
 
     RETRY: while ( 1 ) {
-        my $ok = 1;
-        try {
-            $count++;
+        $count++;
+        if ( eval {
             my $res = $ua->get( $url );
             die $res->status_line, ': ', $url if ! $res->is_success;
-            my $json = $res->decoded_content;
-            $tmp = decode_json( $json );
+            $tmp = decode_json( $res->decoded_content );
             die $url . ' - error fetching youtube list info!' if ! defined $tmp || ! %$tmp;
+            1 }
+        ) {
+            return $tmp;
         }
-        catch {
-            say "$count/$opt->{retries}  $_"; #
+        else {
+            say "$count/$opt->{retries}  $@"; #
             return if $count == $opt->{retries};
-            $ok = 0;
             sleep $opt->{retries} * 3;
-        };
-        return $tmp if $ok;
+        }
     }
 }
 
@@ -74,14 +72,12 @@ sub get_youtube_list_info {
     my $count = 0;
 
     RETRY: while ( 1 ) {
-        my $ok = 1;
-        try {
-            $count++;
+        $count++;
+        if ( eval {
             my $res = $ua->get( $url );
             die $res->status_line, ': ', $url if ! $res->is_success;
-            my $decoded_content = $res->decoded_content;
             my $date_sort = 0;
-            my $dom = Mojo::DOM->new( $decoded_content );
+            my $dom = Mojo::DOM->new( $res->decoded_content );
             my $uploader = $dom->at( 'meta[itemprop="name"][content]' )->attr( 'content' );
             $dom->find( 'li[class="channels-content-item yt-shelf-grid-item"]' )
                 ->each(
@@ -116,14 +112,15 @@ sub get_youtube_list_info {
                         };
                     }
                 );
+            1 }
+        ) {
+            return $tmp;
         }
-        catch {
-            say "$count/$opt->{retries}  $_";
+        else {
+            say "$count/$opt->{retries}  $@";
             return if $count == $opt->{retries};
-            $ok = 0;
             sleep $opt->{retries} * 3;
-        };
-        return $tmp;
+        }
     }
 }
 
@@ -141,13 +138,11 @@ sub get_vimeo_list_info {
     my $count = 0;
 
     RETRY: while ( 1 ) {
-        my $ok = 1;
-        try {
-            $count++;
+        $count++;
+        if ( eval {
             my $res = $ua->get( $url );
             die $res->status_line, ': ', $url if ! $res->is_success;
-            my $decoded_content = $res->decoded_content;
-            my $dom = Mojo::DOM->new( $decoded_content );
+            my $dom = Mojo::DOM->new( $res->decoded_content );
             my $uploader = $dom->at( 'a[class="user"]' )->text;
             $dom->find( 'div[id="browse_content"] > ol > li[id][data-position]' )
                 ->each(
@@ -166,14 +161,15 @@ sub get_vimeo_list_info {
                     }
                 );
             $next = $dom->at( 'a[rel="next"]' ) ? 1 : 0;
+            1 }
+        ) {
+            return $tmp, $next;
         }
-        catch {
-            say "$count/$opt->{retries}  $_";
+        else {
+            say "$count/$opt->{retries}  $@";
             return if $count == $opt->{retries};
-            $ok = 0;
             sleep $opt->{retries} * 3;
-        };
-        return $tmp, $next if $ok;
+        }
     }
 }
 
@@ -186,15 +182,17 @@ sub get_new_video_url {
     push @cmd, '--socket-timeout', $opt->{timeout};
     push @cmd, '--format', $fmt, '--get-url', '--', $webpage_url;
     my $video_url;
-    try {
+    if ( eval {
         $video_url = uni_capture( @cmd );
         die $webpage_url . ' - could not get new video url!' if ! $video_url;
+        1 }
+    ) {
+        return $video_url;
+    }
+    else {
+        say $@;
+        return;
     }
-    catch {
-        say $_;
-        $video_url = undef;
-    };
-    return $video_url;
 }
 
 
@@ -210,9 +208,8 @@ sub get_download_info {
     my $count = 0;
 
     RETRY: while ( 1 ) {
-        my $ok = 1;
-        try {
-            $count++;
+        $count++;
+        if ( eval {
             print HIDE_CURSOR;
             print $message . '...';
             $json_all = uni_capture( @cmd );
@@ -220,18 +217,19 @@ sub get_download_info {
             print $message . "done.\n";
             print SHOW_CURSOR;
             die $webpage_url . ' - no JSON!' if ! $json_all;
+            1 }
+        ) {
+            last RETRY;
         }
-        catch {
-            say "$count/$opt->{retries}  $webpage_url: $_"; #
+        else {
+            print SHOW_CURSOR;
+            say "$count/$opt->{retries}  $webpage_url: $@"; #
             if ( $count == $opt->{retries} ) {
                 push @{$opt->{error_get_download_infos}}, $webpage_url; # $ex
                 return;
             }
-            $ok = 0;
-            print SHOW_CURSOR;
             sleep $opt->{retries} * 3;
-        };
-        last RETRY if $ok;
+        }
     }
     $opt->{up}++;
     my $tmp = json_to_hash( $opt, $json_all );
