@@ -47,64 +47,64 @@ sub get_filename {
 sub sanitize_for_path {
     my ( $opt, $str ) = @_;
     $str =~ s/^\s+|\s+\z//g;
-    $str =~ s/\s/_/g            if $opt->{replace_spaces};
+    $str =~ s/\s/_/g             if $opt->{replace_spaces};
     #$str =~ s/^\.+//            if $^O eq 'Unix';
-    $str =~ s{["/\\:*?<>&|]}{-}g if $opt->{sanitize_filename};
-    # NTFS unsupported characters:  / \ : " * ? < > |       # 0x00-0x1F
+    $str =~ s{["/\\:*?<>&|]}{-}g if $opt->{sanitize_filename} == 1;
+    $str =~ s{/}{-}g             if $opt->{sanitize_filename} == 2;
+    # NTFS unsupported characters:  / \ : " * ? < > |
     return $str;
 }
 
 
 sub timestamp_to_upload_date {
-    my ( $info, $ex, $video_id, $file ) = @_;
+    my ( $opt, $info, $ex, $video_id, $file ) = @_;
     if ( $info->{$ex}{$video_id}{upload_datetime} =~ /^(\d\d\d\d)-(\d\d)-(\d\d)T(\d\d):(\d\d):(\d\d)\z/ ) {
         my $time = timelocal( $6, $5, $4, $3, $2 - 1, $1 );
         my $ref = File::Touch->new( time => $time );
-        my $count = $ref->touch( encode_fs( $file ) );
+        my $count = $ref->touch( encode_fs( $opt, $file ) );
     }
 }
 
 
 sub encode_fs {
-    my ( $filename ) = @_;
+    my ( $opt, $filename ) = @_;
     my $encoded_filename;
-    if ( eval { $encoded_filename = encode( 'locale_fs', NFC $filename, FB_CROAK  ) } ) {
+    if ( eval { $encoded_filename = encode( 'locale_fs', NFC $filename, FB_CROAK | LEAVE_SRC ) } ) {
         return $encoded_filename;
     }
-    return $filename;
+    elsif ( $opt->{unmappable_filename} ) {
+        require Text::Unidecode;
+        return Text::Unidecode::unidecode( $filename );
+    }
+    else {
+        return $filename;
+    }
 }
 
 
 sub check_mapping_stdout {
-    my $opt = shift;
-    if ( wantarray ) {
-        return @_ if $Encode::Locale::ENCODING_CONSOLE_OUT =~ /^UTF-/i;
-        return @_ if eval { map { encode( 'console_out', $_, FB_CROAK | LEAVE_SRC ) } @_; 1 };
-        if ( $opt->{text_unidecode} ) {
-            my @unidecoded;
-            if ( eval { require Text::Unidecode; @unidecoded = Text::Unidecode::unidecode( @_ ); 1 } ) {
-                return @unidecoded;
+    my ( $opt, $string ) = @_;
+    return $string if $Encode::Locale::ENCODING_CONSOLE_OUT =~ /^UTF-/i;
+    return $string if eval { encode( 'console_out', $string, FB_CROAK | LEAVE_SRC ) };
+    if ( $opt->{text_unidecode} ) {
+        require Text::Unidecode;
+        my @words;
+        for my $word ( split / /, $string ) {
+            my $encoded_word;
+            if ( eval { $encoded_word = encode( 'console_out', $word, FB_CROAK | LEAVE_SRC ) } ) {
+                push @words, $encoded_word;
+            }
+            else {
+                my $unidecoded_word = Text::Unidecode::unidecode( $word );
+                push @words, $unidecoded_word;
             }
         }
-        binmode STDOUT, ':pop';
-        my @encoded_lax = map { encode( 'console_out', NFC $_, sub { '*' } ) } @_;
-        binmode STDOUT, ':encoding(console_out)';
-        return @encoded_lax;
-    }
-    else {
-        return $_[0] if $Encode::Locale::ENCODING_CONSOLE_OUT =~ /^UTF-/i;
-        return $_[0] if eval { encode( 'console_out', $_[0], FB_CROAK | LEAVE_SRC ) };
-        if ( $opt->{text_unidecode} ) {
-            my $unidecoded;
-            if ( eval { require Text::Unidecode; $unidecoded = Text::Unidecode::unidecode( $_[0] ); 1 } ) {
-                return $unidecoded;
-            }
-        }
-        binmode STDOUT, ':pop';
-        my $encoded_lax = encode( 'console_out', NFC $_[0], sub { '*' } );
-        binmode STDOUT, ':encoding(console_out)';
-        return $encoded_lax;
+        return join ' ', @words;
     }
+    binmode STDOUT, ':pop';
+    my $encoded_lax = encode( 'console_out', NFC $string, sub { '*' } );
+    binmode STDOUT, ':encoding(console_out)';
+    return $encoded_lax;
 }
 
 
@@ -167,7 +167,7 @@ sub sec_to_time {
 sub write_json {
     my ( $opt, $file, $h_ref ) = @_;
     my $json = JSON->new->pretty->canonical->utf8->encode( $h_ref );
-    open my $fh, '>', encode_fs( $file ) or die check_mapping_stdout( $opt, $file ) . " $!";
+    open my $fh, '>', encode_fs( $opt, $file ) or die encode_fs( $opt, $file ) . " $!";
     print $fh $json;
     close $fh;
 }
@@ -175,8 +175,8 @@ sub write_json {
 
 sub read_json {
     my ( $opt, $file ) = @_;
-    return {} if ! -f encode_fs( $file );
-    open my $fh, '<', encode_fs( $file ) or die check_mapping_stdout( $opt, $file ) . " $!";
+    return {} if ! -f encode_fs( $opt, $file );
+    open my $fh, '<', encode_fs( $opt, $file ) or die encode_fs( $opt, $file ) . " $!";
     my $json = do { local $/; <$fh> };
     close $fh;
     my $h_ref = JSON->new->utf8->decode( $json ) if $json;
