@@ -17,7 +17,6 @@ use Term::Choose           qw( choose );
 use Term::Choose::Util     qw( print_hash choose_a_dir choose_a_number choose_multi insert_sep );
 use Term::ReadLine::Simple qw();
 use Text::LineFold         qw();
-use Try::Tiny              qw( try catch );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
@@ -29,27 +28,21 @@ use App::YTDL::Helper       qw( write_json read_json uni_capture HIDE_CURSOR SHO
 sub _show_info {
     my ( $opt ) = @_;
     my ( $youtube_dl_version, $ffmpeg_version, $ffprobe_version );
-    try {
-        my @cmd = ( $opt->{youtube_dl}, '--version' );
-        $youtube_dl_version = uni_capture( @cmd );
+    if ( ! eval { $youtube_dl_version = uni_capture( $opt->{youtube_dl}, '--version' ); 1 } ) {
+        $youtube_dl_version = $@;
     }
-    catch {
-        $youtube_dl_version = $_;
-    };
-    try {
-        my @cmd = ( $opt->{ffmpeg}, '-version' );
-        $ffmpeg_version = uni_capture( @cmd );
-        if ( $ffmpeg_version =~ /^ffmpeg version (\S+)/m ) {
+    eval {
+        $ffmpeg_version = uni_capture( $opt->{ffmpeg}, '-version' );
+        if ( $ffmpeg_version && $ffmpeg_version =~ /^ffmpeg version (\S+)/m ) {
             $ffmpeg_version = $1;
         }
         else {
             $ffmpeg_version = '';
         }
     };
-    try {
-        my @cmd = ( $opt->{ffprobe}, '-version' );
-        $ffprobe_version = uni_capture( @cmd );
-        if ( $ffprobe_version =~ /^ffprobe version (\S+)/m ) {
+    eval {
+        $ffprobe_version = uni_capture( $opt->{ffprobe}, '-version' );
+        if ( $ffprobe_version && $ffprobe_version =~ /^ffprobe version (\S+)/m ) {
             $ffprobe_version = $1;
         }
         else {
@@ -248,13 +241,9 @@ sub set_options {
                 print HIDE_CURSOR;
                 say 'Close with ENTER';
                 my @capture;
-                try {
-                    my @cmd = ( $opt->{youtube_dl}, '--list-extractors' );
-                    @capture = uni_capture( @cmd );
+                if ( ! eval { @capture = uni_capture( $opt->{youtube_dl}, '--list-extractors' ); 1 } ) {
+                    say "List extractors: $@";
                 }
-                catch {
-                    say "List extractors: $_";
-                };
                 print SHOW_CURSOR;
                 if ( @capture ) {
                     choose(
